import React from 'react';
import { QuestionCircleOutlined } from '@ant-design/icons';
import style from './index.less';
import {
  DatePicker,
  Select,
  Button,
  Checkbox,
  Row,
  Col,
  Dropdown,
  Menu,
  TreeSelect,
  Tooltip,
  Modal,
  Input,
  message,
} from 'antd';
const { Option } = Select;
const { TextArea } = Input;
import moment from 'moment';
import 'moment/locale/zh-cn';
import locale from 'antd/lib/date-picker/locale/zh_CN';
import { HomeOutlined, FolderOpenOutlined } from '@ant-design/icons';
moment.locale('zh-cn');

const defaultLevelOpt = [
  { value: '1', label: '全部' },
  { value: '2', label: '一级' },
  { value: '3', label: '二级' },
  { value: '4', label: '三级' },
];

export class TopBar extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      fclasslist: [],
      rootTreeData: [], //根节点异步树
      treeLoadedKeys: [],
      treeExpandedKeys: [],
      deptTreeData: [],
      requestData: {
        fclass: '0',
        root: undefined,
        department: undefined,
        level: '2',
        fisvitual: '0',
        hidedept: '0',
      },
      open: false,
      confirmLoading: false,
      description: '',
      levelOpt: defaultLevelOpt,
    };
  }

  /**
   * 表单值改变
   * @param {*} payload
   */
  handleFormChange(payload) {
    let requestData = { ...this.state.requestData, ...payload };
    this.setState({ requestData });
  }

  onChange = (e) => {
    this.setState({ description: e.target.value });
  };

  /**
   * 弹窗确认
   */
  handleOk = () => {
    const { description, requestData } = this.state;
    if (description.length == 0) {
      return message.error('请填写描述信息');
    }
    this.setState({ confirmLoading: true });
    let api =
      '/api/bs/hrmorganization/orgchart/versionRecord?fclass=' +
      requestData.fclass +
      '&description=' +
      description;
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.api_status) {
          this.setState({
            open: false,
            confirmLoading: false,
          });
          message.success('版本记录成功,请重新刷新页面', 2, 3);
        } else {
          message.error('版本记录失败,请联系相关人员处理数据', 2, 3);
        }
      });
  };

  handleExportMenuClick(e) {
    this.props.onExport(e.key == '1' ? 'png' : 'pdf');
  }

  handleExportButtonClick() {
    this.props.onExport('png');
  }

  /**
   * 根节点树数据
   * @param {} parentId
   * @returns
   */
  getNodeTreeNode = (url, merge = true) => {
    fetch(url)
      .then((res) => res.json())
      .then((data) => {
        if (data.api_status) {
          let arr = [];
          if (merge) {
            arr = [...this.state.rootTreeData, ...data.companyTree];
          } else {
            arr = [...data.companyTree];
          }
          arr.map((item, index) => {
            item.icon = <HomeOutlined />;
          });
          this.setState({
            rootTreeData: arr,
          });
        }
      });
  };

  /**
   * 根节点树异步加载
   * @param {} parentId
   * @returns
   */
  onRootLoadData = (treeNode) =>
    new Promise((resolve) => {
      const { id } = treeNode;
      setTimeout(() => {
        const { fclass } = this.state.requestData;
        let api =
          '/api/bs/hrmorganization/orgchart/getSubCompanyTree?subcompany=' +
          id +
          '&fclass=' +
          fclass;
        this.getNodeTreeNode(api);
        resolve(undefined);
      }, 500);
    });

  onRootChange = (value) => {
    const { fclass } = this.state.requestData;
    if (fclass != '0') {
      //顺胜项目二开 增加部门节点树
      this.getDeptTreeData(
        `/api/bs/hrmorganization/orgchart/getDepartmentTree?fclass=${fclass}&subcompany=${value}`,
      );
    }
    this.handleFormChange({ department: undefined, root: value });
  };

  /**
   * 部门节点树
   */
  getDeptTreeData = (url) => {
    fetch(url)
      .then((res) => res.json())
      .then((data) => {
        if (data.api_status) {
          let arr = [...data.departmentTree];
          arr.map((item, index) => {
            item.icon = <FolderOpenOutlined />;
          });
          this.setState({
            deptTreeData: arr,
          });
        }
      });
  };

  onDeptChange = (value, label, extra) => {
    var opt = this.buildLevelOpt(0);
    var level = '1';
    if (value != undefined) {
      level = extra.triggerNode.props.level;
      opt = this.buildLevelOpt(level);
    }
    this.handleFormChange({
      department: value,
      level: level === '1' ? level : `${level + 1}`,
    });
    this.setState({ levelOpt: opt });
  };

  /**
   * 虚拟维度部门层级构建
   */
  buildLevelOpt = (level) => {
    let opt = [{ value: '1', label: '全部' }];
    for (let index = 1; index <= level; index++) {
      opt.push({ value: `${index + 1}`, label: `${index}级` });
    }
    return opt;
  };

  onTreeExpand = (expandedKeys) => {
    this.setState({
      treeExpandedKeys: expandedKeys,
    });
  };

  componentDidMount() {
    this.getSeatchCondition(this.props.url);
  }

  getSeatchCondition = (url) => {
    fetch(url)
      .then((res) => res.json())
      .then((data) => {
        data.companyTree.map((item, index) => {
          item.icon = <HomeOutlined />;
        });
        this.setState({
          fclasslist: data.fclasslist,
          rootTreeData: data.companyTree,
        });
      });
  };

  menu = (
    <Menu
      onClick={this.handleExportMenuClick.bind(this)}
      items={[
        {
          label: '导出图片',
          key: '1',
        },
        // {
        //   label: '导出PDF',
        //   key: '2',
        // },
      ]}
    />
  );

  render() {
    const { disabled, type } = this.props;
    const {
      rootTreeData,
      open,
      confirmLoading,
      treeExpandedKeys,
      requestData,
      deptTreeData,
      levelOpt,
    } = this.state;
    const { fclass, department } = requestData;

    return (
      <div className={style.topbarWrapper}>
        <Row>
          <Col span={6}>
            维度：
            <Select
              defaultValue="0"
              style={{ width: 140 }}
              value={fclass}
              onChange={(value) => {
                const requestData = {
                  fclass: value,
                  root: undefined,
                  department: undefined,
                  level: value == '0' ? '2' : '1',
                  fisvitual: '0',
                  hidedept: '0',
                };
                this.handleFormChange(requestData);
                this.setState({
                  rootTreeData: [],
                  deptTreeData: [],
                  levelOpt:
                    value == '0' ? defaultLevelOpt : this.buildLevelOpt(0),
                });
                this.getNodeTreeNode(
                  `/api/bs/hrmorganization/orgchart/getSubCompanyTree?fclass=${value}`,
                  false,
                );
                this.props.changeFclass(requestData);
              }}
            >
              {this.state.fclasslist.map((item) => (
                <Option key={item.key} value={item.id}>
                  {item.companyname}
                </Option>
              ))}
            </Select>
          </Col>
          <Col span={6}>
            根节点：
            <TreeSelect
              treeDataSimpleMode
              allowClear
              style={{ width: '75%' }}
              value={this.state.requestData.root}
              dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
              placeholder="请选择根节点"
              onChange={this.onRootChange}
              loadData={this.onRootLoadData}
              treeData={rootTreeData}
              treeIcon
            />
          </Col>
          <Col span={6}>
            <Checkbox
              style={{ marginTop: '5px', marginLeft: 100 }}
              checked={this.state.requestData.hidedept == '1'}
              onChange={(e) =>
                this.handleFormChange({
                  hidedept: e.target.checked ? '1' : '0',
                })
              }
            >
              隐藏部门
            </Checkbox>
            <Tooltip
              title="提示:开启后将只显示分部组织架构！！！"
              color="#0082fb"
              placement="rightTop"
            >
              <QuestionCircleOutlined
                style={{ color: '#0082fb', cursor: 'pointer', fontSize: 16 }}
              />
            </Tooltip>
          </Col>
          <Col span={6}>
            部门层级：
            <Select
              style={{ width: 140 }}
              value={this.state.requestData.level}
              onChange={(value) => this.handleFormChange({ level: value })}
            >
              {levelOpt.map((item) => (
                <Option key={item.value} value={item.value}>
                  {item.label}
                </Option>
              ))}
            </Select>
          </Col>
        </Row>
        <Row style={{ marginTop: '15px' }}>
          <Col span={6}>
            <Checkbox
              style={{ marginTop: '5px' }}
              checked={this.state.requestData.fisvitual == '1'}
              onChange={(e) =>
                this.handleFormChange({
                  fisvitual: e.target.checked ? '1' : '0',
                })
              }
            >
              显示虚拟组织
            </Checkbox>
            <Tooltip
              title="提示:若启用虚拟组织，需要在分部自定义表增加字段(名称 fblx) 字段类型 下拉框(0实体 1虚拟) 部门自定义表同上(字段名称 bmlx)。"
              color="#0082fb"
              placement="rightTop"
            >
              <QuestionCircleOutlined
                style={{ color: '#0082fb', cursor: 'pointer', fontSize: 16 }}
              />
            </Tooltip>
          </Col>
          {fclass != '0' ? (
            <Col span={8}>
              部门节点：
              <TreeSelect
                treeDataSimpleMode
                allowClear
                style={{ width: '75%' }}
                value={department}
                dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                placeholder="请选择部门节点"
                onChange={this.onDeptChange}
                treeData={deptTreeData}
                treeIcon
              />
            </Col>
          ) : (
            ''
          )}
          <Col span={10}>
            <Button
              type="primary"
              style={{ marginRight: '10px' }}
              onClick={() => {
                this.props.onSearch(this.state.requestData);
              }}
            >
              查询
            </Button>
            <Dropdown overlay={this.menu}>
              <Button type="primary">导出</Button>
            </Dropdown>
          </Col>
        </Row>
      </div>
    );
  }
}
